| Title: | FIU SDM Course Package |
|---|---|
| Description: | Course material for FIU course on SDM |
| Authors: | Russell Dinnage [aut, cre] (ORCID: <https://orcid.org/0000-0003-0846-2819>) |
| Maintainer: | Russell Dinnage <[email protected]> |
| License: | file LICENSE |
| Version: | 0.0.0.9010 |
| Built: | 2026-05-13 05:57:27 UTC |
| Source: | https://github.com/rdinnager/sdmpack |
Convert a submitted hash code to a learnr document for marking
convert_hash_code( hash_code, assignment_path, rmd_path = tempfile(fileext = ".Rmd"), student = "Test student", run = TRUE )convert_hash_code( hash_code, assignment_path, rmd_path = tempfile(fileext = ".Rmd"), student = "Test student", run = TRUE )
hash_code |
Character. hash code to convert |
assignment_path |
Path to assignment .Rmd |
Always make sure fofpack is up to date before starting any assignment!
fofpack_up_to_date()fofpack_up_to_date()
Invisibly returns TRUE if fofpack is up to date, FALSE otherwise
fofpack_up_to_date()fofpack_up_to_date()
Send an environment to RStudio Session
send_env_to_RStudio(env_from, remove = "dput_to_string")send_env_to_RStudio(env_from, remove = "dput_to_string")
env_from |
The environment to send |
Nothing
This function takes everything in an environment and puts it in another, replacing any existing object with the same names.
set_env(env_from, env_to = rlang::global_env())set_env(env_from, env_to = rlang::global_env())
env_from |
The environment to synchronise with |
env_to |
The environment to synchronise |
Nothing
The following functions have been modified from code in the github repo https://github.com/mattblackwell/qsslearnr Versions of this appear to have proliferated around github and I have no idea who originally wrote this submission system. If you happen to know, please let me know. All versions of this begin with this preamble I reproduce as well: The following function has modified from Colin Rundel's learnrhash package, available at https://github.com/rundel/learnrhash. Many thanks to Professor Rundel, who has developed a fantastic tool for courses that teach R and use the learnr package.
This note is also modified from Professor Rundel's description: Note that when
including these functions in a learnr Rmd document it is necessary that the
server function, submission_server(), be included in an R chunk where
context="server". Conversely, any of the ui functions, *_ui(), must not
be included in an R chunk with a context.
submission_server(input, output) submission_uisubmission_server(input, output) submission_ui
An object of class shiny.tag of length 3.
This function is no longer required because of the new submission system
incorporated directly into assignments.
write_answers(week, where = getwd())write_answers(week, where = getwd())
week |
What week's assignment do you want your answers for? This should be numeric. |
where |
Where do you want it? That is, in which directory on your computer do you want to write the text file. Defaults to your working directory. |
Get a text file of your answers to the assignment that you can upload to Canvas.
The path to a text file with answers
write_answers(3)write_answers(3)